==> 2.1.0.tar.gz: android/src/main/java/com/netmera/netmera_flutter_sdk/FNetmeraWorker.java <==
package com.netmera.netmera_flutter_sdk;

import android.content.Context;
import android.content.Intent;
import android.content.res.AssetManager;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.work.Data;
import androidx.work.OneTimeWorkRequest;
import androidx.work.WorkManager;
import androidx.work.WorkRequest;
import androidx.work.Worker;
import androidx.work.WorkerParameters;

import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.atomic.AtomicBoolean;

import io.flutter.FlutterInjector;
import io.flutter.embedding.engine.FlutterEngine;
import io.flutter.embedding.engine.dart.DartExecutor;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.view.FlutterCallbackInformation;


/**
 * Copyright (c) 2021 Inomera Research.
 *
 * @author Burak Soykal
 */
public class FNetmeraWorker extends Worker implements MethodChannel.MethodCallHandler {

    private static final String INTENT_KEY = "INTENT_KEY";
    private static final String SERVICE_INITIALIZED = "serviceInitialized";
    private static final AtomicBoolean serviceStarted = new AtomicBoolean(false);
    private MethodChannel backgroundChannel;

    private final Context context;
    private final ArrayDeque<List<Object>> queue = new ArrayDeque<>();


    public FNetmeraWorker(@NonNull Context context, @NonNull WorkerParameters workerParams) {
        super(context, workerParams);
        this.context = context;
    }

    public static void createAndStart(Context context, Intent intent) {
        Data inputData = new Data.Builder()
                .putAll(bundleToHashMap(intent.getExtras()))
                .putString(INTENT_KEY, intent.getAction())
                .build();
        WorkRequest request = new OneTimeWorkRequest.Builder(FNetmeraWorker.class).setInputData(inputData).build();
        WorkManager.getInstance(context).enqueue(request);
    }

    private void startService(Context context) {
        FlutterEngine flutterEngine = null;
        synchronized (serviceStarted) {
            if (flutterEngine == null) {
                Long callbackHandle = getFromSharedPref(context, NetmeraFlutterSdkPlugin.CALLBACK_DISPATCHER_HANDLE_KEY);
                FlutterInjector.instance().flutterLoader().ensureInitializationComplete(context, null);
                FlutterCallbackInformation callbackInfo = FlutterCallbackInformation.lookupCallbackInformation(callbackHandle);
                if (callbackInfo == null) return;
                flutterEngine = new FlutterEngine(context);
                AssetManager assetManager = getApplicationContext().getAssets();
                String pathToBundle = FlutterInjector.instance().flutterLoader().findAppBundlePath();
                DartExecutor.DartCallback dartCallback = new DartExecutor.DartCallback(assetManager, pathToBundle, callbackInfo);
                flutterEngine.getDartExecutor().executeDartCallback(dartCallback);
            }
        }

        FlutterInjector.instance().flutterLoader().ensureInitializationComplete(context, null);
        backgroundChannel = new MethodChannel(flutterEngine.getDartExecutor().getBinaryMessenger(), "flutter_nm_sdk_background");
        backgroundChannel.setMethodCallHandler(this);
    }

    @NonNull
    @Override
    public Result doWork() {
        final String action = getInputData().getString(INTENT_KEY);
        final HashMap<String, Object> bundle = new HashMap<>();

        for (Map.Entry<String, Object> entry : getInputData().getKeyValueMap().entrySet()) {
            if (!entry.getKey().equals(INTENT_KEY)) {
                bundle.put(entry.getKey(), entry.getValue());
            }
        }
        new Handler(Looper.getMainLooper()).post(
                new Runnable() {
                    @Override
                    public void run() {
                        startService(context);
                        ArrayList<Object> list = new ArrayList<>();
                        list.add(getFromSharedPref(context, action));
                        list.add(bundle);

                        synchronized (serviceStarted) {
                            if (!serviceStarted.get()) {
                                queue.add(list);
                            } else {
                                backgroundChannel.invokeMethod("", list);
                            }
                        }
                    }
                });
        return Result.success();
    }

    @Override
    public void onMethodCall(@NonNull final MethodCall call, @NonNull final MethodChannel.Result result) {
        new Handler(Looper.getMainLooper()).post(
                new Runnable() {
                    @Override
                    public void run() {
                        if (SERVICE_INITIALIZED.equals(call.method)) {
                            synchronized (serviceStarted) {
                                while (!queue.isEmpty()) {
                                    backgroundChannel.invokeMethod("", queue.remove());
                                }
                                serviceStarted.set(true);
                            }
                        }
                        result.success(null);
                    }
                });
    }

    private static Long getFromSharedPref(Context context, String key) {
        return context.getSharedPreferences(
                NetmeraFlutterSdkPlugin.SHARED_PREFERENCES_KEY,
                Context.MODE_PRIVATE)
                .getLong(key, 0);
    }

    private static HashMap<String, Object> bundleToHashMap(@Nullable Bundle bundle) {
        HashMap<String, Object> map = new HashMap<>();
        if (bundle == null) {
            return map;
        }
        Set<String> keys = bundle.keySet();
        for (String key : keys) {
            map.put(key, bundle.get(key));
        }
        return map;
    }
}

==> 2.1.2-dev.tar.gz: android/src/main/java/com/netmera/netmera_flutter_sdk/FNetmeraWorker.java <==
package com.netmera.netmera_flutter_sdk;

import android.content.Context;
import android.content.Intent;
import android.content.res.AssetManager;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.util.Log;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.work.Data;
import androidx.work.OneTimeWorkRequest;
import androidx.work.WorkManager;
import androidx.work.WorkRequest;
import androidx.work.Worker;
import androidx.work.WorkerParameters;

import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.atomic.AtomicBoolean;

import io.flutter.FlutterInjector;
import io.flutter.embedding.engine.FlutterEngine;
import io.flutter.embedding.engine.dart.DartExecutor;
import io.flutter.embedding.engine.loader.FlutterLoader;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.view.FlutterCallbackInformation;


/**
 * Copyright (c) 2021 Inomera Research.
 *
 * @author Burak Soykal
 */
public class FNetmeraWorker extends Worker implements MethodChannel.MethodCallHandler {

    private static final String INTENT_KEY = "INTENT_KEY";
    private static final String SERVICE_INITIALIZED = "serviceInitialized";
    private static final AtomicBoolean serviceStarted = new AtomicBoolean(false);

    private static MethodChannel backgroundChannel;
    private static FlutterEngine flutterEngine;
    private static FlutterLoader flutterLoader;

    private final Context context;
    private final ArrayDeque<List<Object>> queue = new ArrayDeque<>();


    public FNetmeraWorker(@NonNull Context context, @NonNull WorkerParameters workerParams) {
        super(context, workerParams);
        this.context = context;
        flutterLoader = FlutterInjector.instance().flutterLoader();
    }

    public static void createAndStart(Context context, Intent intent) {
        Data inputData = new Data.Builder()
                .putAll(bundleToHashMap(intent.getExtras()))
                .putString(INTENT_KEY, intent.getAction())
                .build();
        WorkRequest request = new OneTimeWorkRequest.Builder(FNetmeraWorker.class).setInputData(inputData).build();
        WorkManager.getInstance(context).enqueue(request);
    }

    private void startService(final Context context) {

        flutterEngine = new FlutterEngine(context);

        if (!flutterLoader.initialized()) {
            flutterLoader.startInitialization(context);
        }

        Handler callbackHandler = new Handler(Looper.getMainLooper());
        Runnable callback = new Runnable() {
            @Override
            public void run() {
                Long callbackHandle = getFromSharedPref(context, NetmeraFlutterSdkPlugin.CALLBACK_DISPATCHER_HANDLE_KEY);
                FlutterCallbackInformation callbackInfo = FlutterCallbackInformation.lookupCallbackInformation(callbackHandle);
                String pathToBundle = flutterLoader.findAppBundlePath();

                if (flutterEngine != null) {
                    backgroundChannel = new MethodChannel(flutterEngine.getDartExecutor(), "flutter_nm_sdk_background");
                    backgroundChannel.setMethodCallHandler(FNetmeraWorker.this);
                    AssetManager assetManager = getApplicationContext().getAssets();
                    DartExecutor.DartCallback dartCallback = new DartExecutor.DartCallback(assetManager, pathToBundle, callbackInfo);
                    flutterEngine.getDartExecutor().executeDartCallback(dartCallback);
                }
            }
        };

        flutterLoader.ensureInitializationCompleteAsync(context, null, callbackHandler, callback);
    }

    @Override
    public void onStopped() {
        super.onStopped();
        stopEngine();
    }

    public void stopEngine() {
        new Handler(Looper.getMainLooper()).post(new Runnable() {
            @Override
            public void run() {
                if (flutterEngine != null) {
                    flutterEngine.destroy();
                    flutterEngine = null;
                }
            }
        });
    }

    @NonNull
    @Override
    public Result doWork() {
        final String action = getInputData().getString(INTENT_KEY);
        final HashMap<String, Object> bundle = new HashMap<>();

        for (Map.Entry<String, Object> entry : getInputData().getKeyValueMap().entrySet()) {
            if (!entry.getKey().equals(INTENT_KEY)) {
                bundle.put(entry.getKey(), entry.getValue());
            }
        }
        new Handler(Looper.getMainLooper()).post(
                new Runnable() {
                    @Override
                    public void run() {
                        if (flutterEngine == null || flutterLoader == null || backgroundChannel == null) {
                            startService(context);
                        }
                        ArrayList<Object> list = new ArrayList<>();
                        list.add(getFromSharedPref(context, action));
                        list.add(bundle);
                        if (!serviceStarted.get()) {
                            queue.add(list);
                        } else {
                            backgroundChannel.invokeMethod("", list);
                        }
                    }
                });
        return Result.success();
    }

    @Override
    public void onMethodCall(@NonNull final MethodCall call, @NonNull final MethodChannel.Result result) {
        new Handler(Looper.getMainLooper()).post(
                new Runnable() {
                    @Override
                    public void run() {
                        if (SERVICE_INITIALIZED.equals(call.method)) {
                            while (!queue.isEmpty()) {
                                backgroundChannel.invokeMethod("", queue.remove());
                            }
                            serviceStarted.set(true);
                        }
                        result.success(null);
                    }
                });
    }

    private static Long getFromSharedPref(Context context, String key) {
        return context.getSharedPreferences(
                NetmeraFlutterSdkPlugin.SHARED_PREFERENCES_KEY,
                Context.MODE_PRIVATE)
                .getLong(key, 0);
    }

    private static HashMap<String, Object> bundleToHashMap(@Nullable Bundle bundle) {
        HashMap<String, Object> map = new HashMap<>();
        if (bundle == null) {
            return map;
        }
        Set<String> keys = bundle.keySet();
        for (String key : keys) {
            map.put(key, bundle.get(key));
        }
        return map;
    }
}
